@@ -23,7 +23,7 @@
 */
 
 #include <config.h>
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include "gnome-about.h"
 
