@@ -21,16 +21,15 @@
   @NOTATION@
 */
 #include <config.h>
+
+#include <glib/gi18n-lib.h>
+
 #include <libgnome/gnome-macros.h>
-
-/* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
-
-#include "gnome-druid.h"
-#include "gnome-uidefs.h"
-#include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-stock-icons.h>
 
+#include "gnome-uidefs.h"
+#include "gnome-druid.h"
+
 struct _GnomeDruidPrivate
 {
 	GnomeDruidPage *current;
@@ -1140,7 +1139,7 @@ gnome_druid_accessible_get_type (void)
 	static GType type = 0;
 
 	if (!type) {
-		static GTypeInfo tinfo = {
+		GTypeInfo tinfo = {
 			0, /* class size */
 			(GBaseInitFunc) NULL, /* base init */
 			(GBaseFinalizeFunc) NULL, /* base finalize */
@@ -1214,7 +1213,7 @@ gnome_druid_accessible_factory_get_type (void)
 	static GType type = 0;
 
 	if (!type) {
-		static const GTypeInfo tinfo = {
+		const GTypeInfo tinfo = {
 			sizeof (AtkObjectFactoryClass),
 			NULL,           /* base_init */
 			NULL,           /* base_finalize */
